#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

import json
from django.http import HttpResponse
from django.core import serializers


class JSONResponseMixin(object):
    '''
    A mixin that can be used to render a JSON response.
    '''
    response_class = HttpResponse

    def render_to_response(self, obj, **response_kwargs):
        '''
        Returns a JSON response, transforming 'context' to make the payload.
        '''
        response_kwargs['content_type'] = 'application/json'
        return self.response_class(
            self.convert_context_to_json(obj),
            **response_kwargs
        )

    def convert_context_to_json(self, obj):
        '''Convert the context dictionary into a JSON object.'''
        json_obj = serializers.serialize('json', [obj])
        return json.dumps(json_obj)
