#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.views.generic.detail import DetailView
from django.utils.decorators import method_decorator
from frontend.models.loop import Loop
from frontend.models.json_response_mixin import JSONResponseMixin


class LoopBuildView(JSONResponseMixin, DetailView):

    model = Loop
    slug_field = "name"

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(LoopBuildView, self).dispatch(*args, **kwargs)

    def render_to_response(self, context):
        if self.request.is_ajax():
            build = self.object.schedule_build()
            return JSONResponseMixin.render_to_response(self, build)
        else:
            raise NotImplementedError
